@@ -10,3 +10,11 @@ def to_date(day, month, year):
 
 def starts_with(value: str, prefix):
     return value is not None and value.startswith(prefix)
+
+
+def true_if_none(value):
+    return value if isinstance(value, bool) else True
+
+
+def to_boolean(value):
+    return value if isinstance(value, bool) else False
